package
Version:
v0.0.32
Opens a new window with list of versions in this module.
Published: Jul 15, 2026
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package agentlint checks effective RocketClaw agent systems for unsafe permission and delegation combinations.
AgentGraphDOT returns a deterministic Graphviz/DOT task delegation graph for the effective agents under runtimeRoot.
Finding is one lint result line.
type Result struct {
Findings []Finding
}
Result is the complete lint result for one runtime tree.
Lint checks the effective agent system rooted at runtimeRoot.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.