app

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 7, 2026 License: MIT Imports: 22 Imported by: 0

Documentation

Overview

Package app wires the rocketclaw runtime together.

Index

Constants

This section is empty.

Variables

var ErrRestartRequested = errors.New("restart requested")

ErrRestartRequested indicates rocketclaw should exit so a supervisor can restart it.

Functions

func Run

func Run(ctx context.Context, cfg *config.Config, configPath string, logger *slog.Logger) error

Run starts rocketclaw and blocks until the context is canceled or a fatal error occurs.

Types

This section is empty.

Jump to