skel

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Overview

Package skel seeds the embedded rocketclaw skeleton into workspaces.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ListSetupFiles

func ListSetupFiles() ([]string, error)

ListSetupFiles returns every workspace-relative file path that `rocketclaw setup` can materialize.

func ReadSetupFile

func ReadSetupFile(name string) ([]byte, error)

ReadSetupFile returns the bytes for one workspace-relative embedded setup file.

func SyncInWithOverlays

func SyncInWithOverlays(workspace, workDir string, overlays []string, logger *slog.Logger) error

SyncInWithOverlays materializes embedded setup files, configured git overlays, and local overlays into workDir.

Types

type OverlayInfo added in v0.0.2

type OverlayInfo struct {
	Spec, URL, Ref, ClonePath string
}

OverlayInfo describes one configured git overlay materialized by SyncInWithOverlays.

func OverlayInfos added in v0.0.2

func OverlayInfos(workspace, workDir string, overlays []string) []OverlayInfo

OverlayInfos returns normalized configured overlay clone metadata in config order.

Jump to